#########
anime-crc
#########


.. image:: https://img.shields.io/travis/Nekmo/anime-crc.svg?style=flat-square&maxAge=2592000
  :target: https://travis-ci.org/Nekmo/anime-crc
  :alt: Latest Travis CI build status

.. image:: https://img.shields.io/pypi/v/anime-crc.svg?style=flat-square
  :target: https://pypi.org/project/anime-crc/
  :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/pyversions/anime-crc.svg?style=flat-square
  :target: https://pypi.org/project/anime-crc/
  :alt: Python versions

.. image:: https://img.shields.io/codeclimate/github/Nekmo/anime-crc.svg?style=flat-square
  :target: https://codeclimate.com/github/Nekmo/anime-crc
  :alt: Code Climate

.. image:: https://img.shields.io/codecov/c/github/Nekmo/anime-crc/master.svg?style=flat-square
  :target: https://codecov.io/github/Nekmo/anime-crc
  :alt: Test coverage

.. image:: https://img.shields.io/requires/github/Nekmo/anime-crc.svg?style=flat-square
     :target: https://requires.io/github/Nekmo/anime-crc/requirements/?branch=master
     :alt: Requirements Status

Validate and create CRC checksums for files (ex. anime video [ABCD01234].mkv)

To install anime-crc, run this command in your terminal:

.. code-block:: console

    $ sudo pip install anime-crc

This is the preferred method to install anime-crc, as it will always install the most recent stable release.
